@@ -28,7 +28,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include <gtkmathview.h>
 #include "guiGTK.h"
 
 #define XLINK_NS_URI "http://www.w3.org/1999/xlink"
@@ -180,7 +179,7 @@ GUI_load_document(GdomeDocument* doc)
 
   math_view = GTK_MATH_VIEW(main_area);
 
-  if (!gtk_math_view_load_doc(math_view, doc)) return -1;
+  if (!gtk_math_view_load_document(math_view, doc)) return -1;
 
   return 0;
 }
